@@ -15,25 +15,23 @@ from __future__ import absolute_import
 import os
 import sys
 import six
+import json
 import copy
 import base64
 from .toolbox import retry
+from rfc3987 import parse as urlparse
 from .toolbox import DoesNotExistError
 from .toolbox import DuplicateObjectError
 from .toolbox import credentials_required
 from .toolbox import CredentialsFailedError
 from dateutil.parser import parse as dateparser
-from .MultipartPostHandler import MultipartPostHandler
+from .MultipartPostHandler import MultipartPostHandler, PostHandler
 if six.PY3:
     import urllib.parse
     import urllib.error
     import urllib.request
 else:
     from six.moves import urllib
-try:
-    import json
-except ImportError:
-    import simplejson as json
 
 
 #
@@ -178,6 +176,16 @@ class DocumentClient(BaseDocumentCloudClient):
         # later. Storing it will preserve the credentials.
         self._connection = connection
 
+    def is_url(self, string):
+        """
+        Test if a pdf being submitted is a valid URL
+        """
+        try:
+            urlparse(string, rule="IRI")
+            return True
+        except:
+            return False
+
     def _get_search_page(self, query, page, per_page):
         """
         Retrieve one page of search results from the DocumentCloud API.
@@ -259,19 +267,25 @@ class DocumentClient(BaseDocumentCloudClient):
         Based on code developed by Mitchell Kotler and
         refined by Christopher Groskopf.
         """
-        # Required parameters
+        # Required pdf parameter
         if hasattr(pdf, 'read'):
             try:
                 size = os.fstat(pdf.fileno()).st_size
             except:
                 size = 0
             params = {'file': pdf}
+            opener = MultipartPostHandler
+        elif self.is_url(pdf):
+            size = 0
+            params = {'file': pdf}
+            opener = PostHandler  # URL uploads don't need MultiPart
         else:
             size = os.path.getsize(pdf)
             params = {'file': open(pdf, 'rb')}
+            opener = MultipartPostHandler
         # Enforce file size limit of the DocumentCloud API
         if size >= 399999999:
-            raise ValueError("The pdf you have submited if over the \
+            raise ValueError("The pdf you have submitted is over the \
 DocumentCloud API's 400MB file size limit. Split it into smaller pieces \
 and try again.")
         # Optional parameters
@@ -305,7 +319,7 @@ and try again.")
         response = self._make_request(
             self.BASE_URI + 'upload.json',
             params,
-            MultipartPostHandler
+            opener=opener
         )
         return self.get(json.loads(response.decode("utf-8"))['id'])
 
